Documentation
¶
Index ¶
Constants ¶
const ( FETCH_SOURCE = iota FETCH_DEPLOYMENT FETCH_URL // remove this? )
const ( // ArchiveTypeLiteral means the package contents are specified in the Literal field of // resource itself. ArchiveTypeLiteral = fv1.ArchiveTypeLiteral // ArchiveTypeUrl means the package contents are at the specified URL. ArchiveTypeUrl = fv1.ArchiveTypeUrl )
const ( BuildStatusPending = fv1.BuildStatusPending BuildStatusRunning = fv1.BuildStatusRunning BuildStatusSucceeded = fv1.BuildStatusSucceeded BuildStatusFailed = fv1.BuildStatusFailed BuildStatusNone = fv1.BuildStatusNone )
const ( AllowedFunctionsPerContainerSingle = fv1.AllowedFunctionsPerContainerSingle AllowedFunctionsPerContainerInfinite = fv1.AllowedFunctionsPerContainerInfinite )
const ( ENVIRONMENT_NAMESPACE = "environmentNamespace" ENVIRONMENT_NAME = "environmentName" ENVIRONMENT_UID = "environmentUid" FUNCTION_NAMESPACE = "functionNamespace" FUNCTION_NAME = "functionName" FUNCTION_UID = "functionUid" FUNCTION_RESOURCE_VERSION = "functionResourceVersion" EXECUTOR_TYPE = "executorType" )
executor kubernetes object label key
const ( )
const ( MessageQueueTypeNats = fv1.MessageQueueTypeNats MessageQueueTypeASQ = fv1.MessageQueueTypeASQ MessageQueueTypeKafka = fv1.MessageQueueTypeKafka )
const ( // FunctionReferenceFunctionName means that the function // reference is simply by function name. FunctionReferenceTypeFunctionName = fv1.FunctionReferenceTypeFunctionName // Set of function references (recursively), by percentage of traffic FunctionReferenceTypeFunctionWeights = fv1.FunctionReferenceTypeFunctionWeights )
const ( FissionBuilderSA = "fission-builder" FissionFetcherSA = "fission-fetcher" SecretConfigMapGetterCR = "secret-configmap-getter" SecretConfigMapGetterRB = "secret-configmap-getter-binding" PackageGetterCR = "package-getter" PackageGetterRB = "package-getter-binding" ClusterRole = "ClusterRole" )
const ( FailureTypeStatusCode = fv1.FailureTypeStatusCode CanaryConfigStatusPending = fv1.CanaryConfigStatusPending CanaryConfigStatusSucceeded = fv1.CanaryConfigStatusSucceeded CanaryConfigStatusFailed = fv1.CanaryConfigStatusFailed CanaryConfigStatusAborted = fv1.CanaryConfigStatusAborted MaxIterationsForCanaryConfig = fv1.MaxIterationsForCanaryConfig )
const (
ANNOTATION_SVC_HOST = "svcHost"
)
const (
ArchiveLiteralSizeLimit int64 = 256 * 1024
)
const (
ChecksumTypeSHA256 = fv1.ChecksumTypeSHA256
)
const EXECUTOR_INSTANCEID_LABEL = fv1.EXECUTOR_INSTANCEID_LABEL
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ArchiveUploadRequest ¶
type ArchiveUploadRequest struct {
Filename string `json:"filename"`
StorageSvcUrl string `json:"storagesvcurl"`
ArchivePackage bool `json:"archivepackage"`
}
ArchiveUploadRequest send from builder manager describes which deployment package should be upload to storage service.
type ArchiveUploadResponse ¶
type ArchiveUploadResponse struct {
ArchiveDownloadUrl string `json:"archiveDownloadUrl"`
Checksum fv1.Checksum `json:"checksum"`
}
ArchiveUploadResponse defines the download url of an archive and its checksum.
type FetchRequestType ¶
type FetchRequestType int
Fission-Environment interface. The following types are not exposed in the Fission API, but rather used by Fission to talk to environments.
type FunctionFetchRequest ¶
type FunctionFetchRequest struct {
FetchType FetchRequestType `json:"fetchType"`
Package metav1.ObjectMeta `json:"package"`
Url string `json:"url"`
StorageSvcUrl string `json:"storagesvcurl"`
Filename string `json:"filename"`
Secrets []fv1.SecretReference `json:"secretList"`
ConfigMaps []fv1.ConfigMapReference `json:"configMapList"`
KeepArchive bool `json:"keeparchive"`
}
Fission-Environment interface. The following types are not exposed in the Fission API, but rather used by Fission to talk to environments.
type FunctionLoadRequest ¶
type FunctionLoadRequest struct {
// FilePath is an absolute filesystem path to the
// function. What exactly is stored here is
// env-specific. Optional.
FilePath string `json:"filepath"`
// FunctionName has an environment-specific meaning;
// usually, it defines a function within a module
// containing multiple functions. Optional; default is
// environment-specific.
FunctionName string `json:"functionName"`
// URL to expose this function at. Optional; defaults
// to "/".
URL string `json:"url"`
// Metatdata
FunctionMetadata *metav1.ObjectMeta
EnvVersion int `json:"envVersion"`
}
Fission-Environment interface. The following types are not exposed in the Fission API, but rather used by Fission to talk to environments.
type FunctionSpecializeRequest ¶
type FunctionSpecializeRequest struct {
FetchReq FunctionFetchRequest
LoadReq FunctionLoadRequest
}
Fission-Environment interface. The following types are not exposed in the Fission API, but rather used by Fission to talk to environments.