webhook

package
v1.22.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 16, 2025 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Start

func Start(ctx context.Context, clientGen crd.ClientGeneratorInterface, logger *zap.Logger, options webhook.Options) (err error)

Types

type CanaryConfig added in v1.21.0

type CanaryConfig struct{}

func (*CanaryConfig) Default added in v1.21.0

func (r *CanaryConfig) Default(_ context.Context, obj runtime.Object) error

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*CanaryConfig) SetupWebhookWithManager added in v1.21.0

func (r *CanaryConfig) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*CanaryConfig) ValidateCreate added in v1.21.0

func (r *CanaryConfig) ValidateCreate(_ context.Context, obj runtime.Object) (admission.Warnings, error)

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*CanaryConfig) ValidateDelete added in v1.21.0

func (r *CanaryConfig) ValidateDelete(_ context.Context, _ runtime.Object) (admission.Warnings, error)

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*CanaryConfig) ValidateUpdate added in v1.21.0

func (r *CanaryConfig) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type Environment added in v1.21.0

type Environment struct{}

func (*Environment) Default added in v1.21.0

func (r *Environment) Default(_ context.Context, obj runtime.Object) error

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*Environment) SetupWebhookWithManager added in v1.21.0

func (r *Environment) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*Environment) ValidateCreate added in v1.21.0

func (r *Environment) ValidateCreate(_ context.Context, obj runtime.Object) (admission.Warnings, error)

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*Environment) ValidateDelete added in v1.21.0

func (r *Environment) ValidateDelete(_ context.Context, _ runtime.Object) (admission.Warnings, error)

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*Environment) ValidateUpdate added in v1.21.0

func (r *Environment) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type Function added in v1.21.0

type Function struct{}

func (*Function) Default added in v1.21.0

func (r *Function) Default(_ context.Context, obj runtime.Object) error

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*Function) SetupWebhookWithManager added in v1.21.0

func (r *Function) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*Function) ValidateCreate added in v1.21.0

func (r *Function) ValidateCreate(_ context.Context, obj runtime.Object) (admission.Warnings, error)

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*Function) ValidateDelete added in v1.21.0

func (r *Function) ValidateDelete(_ context.Context, _ runtime.Object) (admission.Warnings, error)

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*Function) ValidateUpdate added in v1.21.0

func (r *Function) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type HTTPTrigger added in v1.21.0

type HTTPTrigger struct{}

func (*HTTPTrigger) Default added in v1.21.0

func (r *HTTPTrigger) Default(_ context.Context, obj runtime.Object) error

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*HTTPTrigger) SetupWebhookWithManager added in v1.21.0

func (r *HTTPTrigger) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*HTTPTrigger) ValidateCreate added in v1.21.0

func (r *HTTPTrigger) ValidateCreate(_ context.Context, obj runtime.Object) (admission.Warnings, error)

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*HTTPTrigger) ValidateDelete added in v1.21.0

func (r *HTTPTrigger) ValidateDelete(_ context.Context, _ runtime.Object) (admission.Warnings, error)

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*HTTPTrigger) ValidateUpdate added in v1.21.0

func (r *HTTPTrigger) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type KubernetesWatchTrigger added in v1.21.0

type KubernetesWatchTrigger struct{}

func (*KubernetesWatchTrigger) Default added in v1.21.0

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*KubernetesWatchTrigger) SetupWebhookWithManager added in v1.21.0

func (r *KubernetesWatchTrigger) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*KubernetesWatchTrigger) ValidateCreate added in v1.21.0

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*KubernetesWatchTrigger) ValidateDelete added in v1.21.0

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*KubernetesWatchTrigger) ValidateUpdate added in v1.21.0

func (r *KubernetesWatchTrigger) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type MessageQueueTrigger added in v1.21.0

type MessageQueueTrigger struct{}

func (*MessageQueueTrigger) Default added in v1.21.0

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*MessageQueueTrigger) SetupWebhookWithManager added in v1.21.0

func (r *MessageQueueTrigger) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*MessageQueueTrigger) ValidateCreate added in v1.21.0

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*MessageQueueTrigger) ValidateDelete added in v1.21.0

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*MessageQueueTrigger) ValidateUpdate added in v1.21.0

func (r *MessageQueueTrigger) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type Package added in v1.21.0

type Package struct{}

func (*Package) Default added in v1.21.0

func (r *Package) Default(_ context.Context, obj runtime.Object) error

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*Package) SetupWebhookWithManager added in v1.21.0

func (r *Package) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*Package) ValidateCreate added in v1.21.0

func (r *Package) ValidateCreate(_ context.Context, obj runtime.Object) (admission.Warnings, error)

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*Package) ValidateDelete added in v1.21.0

func (r *Package) ValidateDelete(_ context.Context, _ runtime.Object) (admission.Warnings, error)

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*Package) ValidateUpdate added in v1.21.0

func (r *Package) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type TimeTrigger added in v1.21.0

type TimeTrigger struct{}

func (*TimeTrigger) Default added in v1.21.0

func (r *TimeTrigger) Default(_ context.Context, obj runtime.Object) error

Default implements webhook.CustomDefaulter so a webhook will be registered for the type

func (*TimeTrigger) SetupWebhookWithManager added in v1.21.0

func (r *TimeTrigger) SetupWebhookWithManager(mgr ctrl.Manager) error

func (*TimeTrigger) ValidateCreate added in v1.21.0

func (r *TimeTrigger) ValidateCreate(_ context.Context, obj runtime.Object) (admission.Warnings, error)

ValidateCreate implements webhook.CustomValidator so a webhook will be registered for the type

func (*TimeTrigger) ValidateDelete added in v1.21.0

func (r *TimeTrigger) ValidateDelete(_ context.Context, _ runtime.Object) (admission.Warnings, error)

ValidateDelete implements webhook.CustomValidator so a webhook will be registered for the type

func (*TimeTrigger) ValidateUpdate added in v1.21.0

func (r *TimeTrigger) ValidateUpdate(_ context.Context, oldObj, newObj runtime.Object) (admission.Warnings, error)

ValidateUpdate implements webhook.CustomValidator so a webhook will be registered for the type

type WebhookInjector

type WebhookInjector interface {
	SetupWebhookWithManager(mgr manager.Manager) error
}

Jump to